@@ -45,7 +45,7 @@ static TQString s_description;
 static TQString s_appName;
 static TQString s_version;
 static TQString s_homepage;
-static KAboutData* s_pAboutData;
+static TDEAboutData* s_pAboutData;
 
 
 #ifdef _WIN32
@@ -286,7 +286,7 @@ TQString KFileDialog::getSaveFileName (const TQString &startDir,
 }
 
 
-KToolBar::BarPosition KToolBar::barPos()
+TDEToolBar::BarPosition TDEToolBar::barPos()
 {
    if ( m_pMainWindow->leftDock()->hasDockWindow(this) ) return Left;
    if ( m_pMainWindow->rightDock()->hasDockWindow(this) ) return Right;
@@ -295,7 +295,7 @@ KToolBar::BarPosition KToolBar::barPos()
    return Top;
 }
 
-void KToolBar::setBarPos(BarPosition bp)
+void TDEToolBar::setBarPos(BarPosition bp)
 {
    if ( bp == Left ) m_pMainWindow->moveDockWindow( this, DockLeft );
    else if ( bp == Right ) m_pMainWindow->moveDockWindow( this, DockRight );
@@ -303,14 +303,14 @@ void KToolBar::setBarPos(BarPosition bp)
    else if ( bp == Top ) m_pMainWindow->moveDockWindow( this, DockTop );
 }
 
-KToolBar::KToolBar( TQMainWindow* parent )
+TDEToolBar::TDEToolBar( TQMainWindow* parent )
 : TQToolBar( parent )
 {
    m_pMainWindow = parent;
 }
 
 
-KMainWindow::KMainWindow( TQWidget* parent, const char* name )
+TDEMainWindow::TDEMainWindow( TQWidget* parent, const char* name )
 : TQMainWindow( parent, name ), m_actionCollection(this)
 {
    fileMenu = new TQPopupMenu();
@@ -334,30 +334,30 @@ KMainWindow::KMainWindow( TQWidget* parent, const char* name )
    helpMenu = new TQPopupMenu();
    menuBar()->insertItem(i18n("&Help"), helpMenu);
 
-   m_pToolBar = new KToolBar(this);
+   m_pToolBar = new TDEToolBar(this);
       
-   memberList = new TQList<KMainWindow>;
+   memberList = new TQList<TDEMainWindow>;
    memberList->append(this);
 }
 
-KToolBar* KMainWindow::toolBar(const TQString&)
+TDEToolBar* TDEMainWindow::toolBar(const TQString&)
 {
    return m_pToolBar;
 }
 
-KActionCollection* KMainWindow::actionCollection()
+TDEActionCollection* TDEMainWindow::actionCollection()
 {
    return &m_actionCollection;
 }
 
-void KMainWindow::createGUI()
+void TDEMainWindow::createGUI()
 {
    KStdAction::help(this, TQT_SLOT(slotHelp()), actionCollection());
    KStdAction::about(this, TQT_SLOT(slotAbout()), actionCollection());
    KStdAction::aboutTQt(actionCollection());
 }
 
-void KMainWindow::slotAbout()
+void TDEMainWindow::slotAbout()
 {
    TQTabDialog d;
    d.setCaption("About " + s_appName);
@@ -372,7 +372,7 @@ void KMainWindow::slotAbout()
       );
    d.addTab(tb1,i18n("&About"));
       
-   std::list<KAboutData::AboutDataEntry>::iterator i;
+   std::list<TDEAboutData::AboutDataEntry>::iterator i;
    
    TQString s2;   
    for( i=s_pAboutData->m_authorList.begin(); i!=s_pAboutData->m_authorList.end(); ++i )
@@ -417,13 +417,13 @@ void KMainWindow::slotAbout()
 */
 }
 
-void KMainWindow::slotHelp()
+void TDEMainWindow::slotHelp()
 {
    showHelp();
 }
 
 
-TQString KStandardDirs::findResource(const TQString& resource, const TQString& /*appName*/)
+TQString TDEStandardDirs::findResource(const TQString& resource, const TQString& /*appName*/)
 {
    if (resource=="config")
    {
@@ -433,11 +433,11 @@ TQString KStandardDirs::findResource(const TQString& resource, const TQString& /
    return TQString();
 }
 
-KConfig::KConfig()
+TDEConfig::TDEConfig()
 {
 }
 
-void KConfig::readConfigFile( const TQString& configFileName )
+void TDEConfig::readConfigFile( const TQString& configFileName )
 {
    if ( !configFileName.isEmpty() )
    {
@@ -445,7 +445,7 @@ void KConfig::readConfigFile( const TQString& configFileName )
    }
    else
    {
-      m_fileName = KStandardDirs().findResource("config","kdiff3rc");
+      m_fileName = TDEStandardDirs().findResource("config","kdiff3rc");
    }
 
    TQFile f( m_fileName );
@@ -457,7 +457,7 @@ void KConfig::readConfigFile( const TQString& configFileName )
    }
 }
 
-KConfig::~KConfig()
+TDEConfig::~TDEConfig()
 {
    TQFile f(m_fileName);
    if ( f.open( IO_WriteOnly | IO_Translate ) )
@@ -468,15 +468,15 @@ KConfig::~KConfig()
    }
 }
 
-void KConfig::setGroup(const TQString&)
+void TDEConfig::setGroup(const TQString&)
 {
 }
 
-void KAction::init(TQObject* receiver, const char* slot, KActionCollection* actionCollection, 
+void TDEAction::init(TQObject* receiver, const char* slot, TDEActionCollection* actionCollection, 
                    const char* name, bool bToggle, bool bMenu)
 {
    TQString n(name);
-   KMainWindow* p = actionCollection->m_pMainWindow;
+   TDEMainWindow* p = actionCollection->m_pMainWindow;
    if( slot!=0 )
    {
       if (!bToggle)
@@ -521,20 +521,20 @@ void KAction::init(TQObject* receiver, const char* slot, KActionCollection* acti
 }
 
 
-KAction::KAction(const TQString& text, const TQIconSet& icon, int accel,
- TQObject* receiver, const char* slot, KActionCollection* actionCollection,
+TDEAction::TDEAction(const TQString& text, const TQIconSet& icon, int accel,
+ TQObject* receiver, const char* slot, TDEActionCollection* actionCollection,
  const char* name, bool bToggle, bool bMenu
  )
 : TQAction ( text, icon, text, accel, actionCollection->m_pMainWindow, name, bToggle )
 {
-   KMainWindow* p = actionCollection->m_pMainWindow;
+   TDEMainWindow* p = actionCollection->m_pMainWindow;
    if ( !icon.isNull() && p ) this->addTo( p->m_pToolBar );
 
    init(receiver,slot,actionCollection,name,bToggle,bMenu);
 }
 
-KAction::KAction(const TQString& text, int accel,
- TQObject* receiver, const char* slot, KActionCollection* actionCollection,
+TDEAction::TDEAction(const TQString& text, int accel,
+ TQObject* receiver, const char* slot, TDEActionCollection* actionCollection,
  const char* name, bool bToggle, bool bMenu
  )
 : TQAction ( text, text, accel, actionCollection->m_pMainWindow, name, bToggle )
@@ -542,39 +542,39 @@ KAction::KAction(const TQString& text, int accel,
    init(receiver,slot,actionCollection,name,bToggle,bMenu);
 }
 
-void KAction::setStatusText(const TQString&)
+void TDEAction::setStatusText(const TQString&)
 {
 }
 
-void KAction::plug(TQPopupMenu* menu)
+void TDEAction::plug(TQPopupMenu* menu)
 {
    addTo(menu);
 }
 
 
-KToggleAction::KToggleAction(const TQString& text, const TQIconSet& icon, int accel, TQObject* receiver, const char* slot, KActionCollection* actionCollection, const char* name, bool bMenu)
-: KAction( text, icon, accel, receiver, slot, actionCollection, name, true, bMenu)
+TDEToggleAction::TDEToggleAction(const TQString& text, const TQIconSet& icon, int accel, TQObject* receiver, const char* slot, TDEActionCollection* actionCollection, const char* name, bool bMenu)
+: TDEAction( text, icon, accel, receiver, slot, actionCollection, name, true, bMenu)
 {
 }
 
-KToggleAction::KToggleAction(const TQString& text, int accel, TQObject* receiver, const char* slot, KActionCollection* actionCollection, const char* name, bool bMenu)
-: KAction( text, accel, receiver, slot, actionCollection, name, true, bMenu)
+TDEToggleAction::TDEToggleAction(const TQString& text, int accel, TQObject* receiver, const char* slot, TDEActionCollection* actionCollection, const char* name, bool bMenu)
+: TDEAction( text, accel, receiver, slot, actionCollection, name, true, bMenu)
 {
 }
 
-KToggleAction::KToggleAction(const TQString& text, const TQIconSet& icon, int accel, KActionCollection* actionCollection, const char* name, bool bMenu)
-: KAction( text, icon, accel, 0, 0, actionCollection, name, true, bMenu)
+TDEToggleAction::TDEToggleAction(const TQString& text, const TQIconSet& icon, int accel, TDEActionCollection* actionCollection, const char* name, bool bMenu)
+: TDEAction( text, icon, accel, 0, 0, actionCollection, name, true, bMenu)
 {
 }
 
-void KToggleAction::setChecked(bool bChecked)
+void TDEToggleAction::setChecked(bool bChecked)
 {
    blockSignals( true );
    setOn( bChecked );
    blockSignals( false );
 }
 
-bool KToggleAction::isChecked()
+bool TDEToggleAction::isChecked()
 {
    return isOn();
 }
@@ -582,144 +582,144 @@ bool KToggleAction::isChecked()
 
 
 //static
-KAction* KStdAction::open( TQWidget* parent, const char* slot, KActionCollection* actionCollection)
+TDEAction* KStdAction::open( TQWidget* parent, const char* slot, TDEActionCollection* actionCollection)
 {
    #include "../xpm/fileopen.xpm"
-   KMainWindow* p = actionCollection->m_pMainWindow;
-   KAction* a = new KAction( i18n("Open"), TQIconSet(TQPixmap(fileopen)), TQt::CTRL+TQt::Key_O, parent, slot, actionCollection, "open", false, false);
+   TDEMainWindow* p = actionCollection->m_pMainWindow;
+   TDEAction* a = new TDEAction( i18n("Open"), TQIconSet(TQPixmap(fileopen)), TQt::CTRL+TQt::Key_O, parent, slot, actionCollection, "open", false, false);
    if(p){ a->addTo( p->fileMenu ); }
    return a;
 }
 
-KAction* KStdAction::save( TQWidget* parent, const char* slot, KActionCollection* actionCollection )
+TDEAction* KStdAction::save( TQWidget* parent, const char* slot, TDEActionCollection* actionCollection )
 {
    #include "../xpm/filesave.xpm"
-   KMainWindow* p = actionCollection->m_pMainWindow;
-   KAction* a = new KAction( i18n("Save"), TQIconSet(TQPixmap(filesave)), TQt::CTRL+TQt::Key_S, parent, slot, actionCollection, "save", false, false);
+   TDEMainWindow* p = actionCollection->m_pMainWindow;
+   TDEAction* a = new TDEAction( i18n("Save"), TQIconSet(TQPixmap(filesave)), TQt::CTRL+TQt::Key_S, parent, slot, actionCollection, "save", false, false);
    if(p){ a->addTo( p->fileMenu ); }
    return a;
 }
 
-KAction* KStdAction::saveAs( TQWidget* parent, const char* slot, KActionCollection* actionCollection)
+TDEAction* KStdAction::saveAs( TQWidget* parent, const char* slot, TDEActionCollection* actionCollection)
 {
-   KMainWindow* p = actionCollection->m_pMainWindow;
-   KAction* a = new KAction( i18n("Save As..."), 0, parent, slot, actionCollection, "saveas", false, false);
+   TDEMainWindow* p = actionCollection->m_pMainWindow;
+   TDEAction* a = new TDEAction( i18n("Save As..."), 0, parent, slot, actionCollection, "saveas", false, false);
    if(p) a->addTo( p->fileMenu );
    return a;
 }
 
-KAction* KStdAction::print( TQWidget* parent, const char* slot, KActionCollection* actionCollection)
+TDEAction* KStdAction::print( TQWidget* parent, const char* slot, TDEActionCollection* actionCollection)
 {
    #include "../xpm/fileprint.xpm"
-   KMainWindow* p = actionCollection->m_pMainWindow;
-   KAction* a = new KAction( i18n("Print..."), TQIconSet(TQPixmap(fileprint)),TQt::CTRL+TQt::Key_P, parent, slot, actionCollection, "print", false, false);
+   TDEMainWindow* p = actionCollection->m_pMainWindow;
+   TDEAction* a = new TDEAction( i18n("Print..."), TQIconSet(TQPixmap(fileprint)),TQt::CTRL+TQt::Key_P, parent, slot, actionCollection, "print", false, false);
    if(p) a->addTo( p->fileMenu );
    return a;
 }
 
-KAction* KStdAction::quit( TQWidget* parent, const char* slot, KActionCollection* actionCollection)
+TDEAction* KStdAction::quit( TQWidget* parent, const char* slot, TDEActionCollection* actionCollection)
 {
-   KMainWindow* p = actionCollection->m_pMainWindow;
-   KAction* a = new KAction( i18n("Quit"), TQt::CTRL+TQt::Key_Q, parent, slot, actionCollection, "quit", false, false);
+   TDEMainWindow* p = actionCollection->m_pMainWindow;
+   TDEAction* a = new TDEAction( i18n("Quit"), TQt::CTRL+TQt::Key_Q, parent, slot, actionCollection, "quit", false, false);
    if(p) a->addTo( p->fileMenu );
    return a;
 }
 
-KAction* KStdAction::cut( TQWidget* parent, const char* slot, KActionCollection* actionCollection)
+TDEAction* KStdAction::cut( TQWidget* parent, const char* slot, TDEActionCollection* actionCollection)
 {
-   KMainWindow* p = actionCollection->m_pMainWindow;
-   KAction* a = new KAction( i18n("Cut"), TQt::CTRL+TQt::Key_X, parent, slot, actionCollection, "cut", false, false );
+   TDEMainWindow* p = actionCollection->m_pMainWindow;
+   TDEAction* a = new TDEAction( i18n("Cut"), TQt::CTRL+TQt::Key_X, parent, slot, actionCollection, "cut", false, false );
    if(p) a->addTo( p->editMenu );
    return a;
 }
 
-KAction* KStdAction::copy( TQWidget* parent, const char* slot, KActionCollection* actionCollection)
+TDEAction* KStdAction::copy( TQWidget* parent, const char* slot, TDEActionCollection* actionCollection)
 {
-   KMainWindow* p = actionCollection->m_pMainWindow;
-   KAction* a = new KAction( i18n("Copy"), TQt::CTRL+TQt::Key_C, parent, slot, actionCollection, "copy", false, false );
+   TDEMainWindow* p = actionCollection->m_pMainWindow;
+   TDEAction* a = new TDEAction( i18n("Copy"), TQt::CTRL+TQt::Key_C, parent, slot, actionCollection, "copy", false, false );
    if(p) a->addTo( p->editMenu );
    return a;
 }
 
-KAction* KStdAction::paste( TQWidget* parent, const char* slot, KActionCollection* actionCollection)
+TDEAction* KStdAction::paste( TQWidget* parent, const char* slot, TDEActionCollection* actionCollection)
 {
-   KMainWindow* p = actionCollection->m_pMainWindow;
-   KAction* a = new KAction( i18n("Paste"), TQt::CTRL+TQt::Key_V, parent, slot, actionCollection, "paste", false, false );
+   TDEMainWindow* p = actionCollection->m_pMainWindow;
+   TDEAction* a = new TDEAction( i18n("Paste"), TQt::CTRL+TQt::Key_V, parent, slot, actionCollection, "paste", false, false );
    if(p) a->addTo( p->editMenu );
    return a;
 }
 
-KAction* KStdAction::selectAll( TQWidget* parent, const char* slot, KActionCollection* actionCollection)
+TDEAction* KStdAction::selectAll( TQWidget* parent, const char* slot, TDEActionCollection* actionCollection)
 {
-   KMainWindow* p = actionCollection->m_pMainWindow;
-   KAction* a = new KAction( i18n("Select All"), TQt::CTRL+TQt::Key_A, parent, slot, actionCollection, "selectall", false, false );
+   TDEMainWindow* p = actionCollection->m_pMainWindow;
+   TDEAction* a = new TDEAction( i18n("Select All"), TQt::CTRL+TQt::Key_A, parent, slot, actionCollection, "selectall", false, false );
    if(p) a->addTo( p->editMenu );
    return a;
 }
 
-KToggleAction* KStdAction::showToolbar( TQWidget* parent, const char* slot, KActionCollection* actionCollection)
+TDEToggleAction* KStdAction::showToolbar( TQWidget* parent, const char* slot, TDEActionCollection* actionCollection)
 {
-   KMainWindow* p = actionCollection->m_pMainWindow;
-   KToggleAction* a = new KToggleAction( i18n("Show Toolbar"), 0, parent, slot, actionCollection, "showtoolbar", false );
+   TDEMainWindow* p = actionCollection->m_pMainWindow;
+   TDEToggleAction* a = new TDEToggleAction( i18n("Show Toolbar"), 0, parent, slot, actionCollection, "showtoolbar", false );
    if(p) a->addTo( p->settingsMenu );
    return a;
 }
 
-KToggleAction* KStdAction::showStatusbar( TQWidget* parent, const char* slot, KActionCollection* actionCollection)
+TDEToggleAction* KStdAction::showStatusbar( TQWidget* parent, const char* slot, TDEActionCollection* actionCollection)
 {
-   KMainWindow* p = actionCollection->m_pMainWindow;
-   KToggleAction* a = new KToggleAction( i18n("Show &Statusbar"), 0, parent, slot, actionCollection, "showstatusbar", false );
+   TDEMainWindow* p = actionCollection->m_pMainWindow;
+   TDEToggleAction* a = new TDEToggleAction( i18n("Show &Statusbar"), 0, parent, slot, actionCollection, "showstatusbar", false );
    if(p) a->addTo( p->settingsMenu );
    return a;
 }
 
-KAction* KStdAction::preferences( TQWidget* parent, const char* slot, KActionCollection* actionCollection)
+TDEAction* KStdAction::preferences( TQWidget* parent, const char* slot, TDEActionCollection* actionCollection)
 {
-   KMainWindow* p = actionCollection->m_pMainWindow;
-   KAction* a = new KAction( i18n("&Configure %1...").arg("KDiff3"), 0, parent, slot, actionCollection, "settings", false, false );
+   TDEMainWindow* p = actionCollection->m_pMainWindow;
+   TDEAction* a = new TDEAction( i18n("&Configure %1...").arg("KDiff3"), 0, parent, slot, actionCollection, "settings", false, false );
    if(p) a->addTo( p->settingsMenu );
    return a;
 }
-KAction* KStdAction::keyBindings( TQWidget*, const char*, KActionCollection*)
+TDEAction* KStdAction::keyBindings( TQWidget*, const char*, TDEActionCollection*)
 {
    return 0;
 }
 
-KAction* KStdAction::about( TQWidget* parent, const char* slot, KActionCollection* actionCollection)
+TDEAction* KStdAction::about( TQWidget* parent, const char* slot, TDEActionCollection* actionCollection)
 {
-   KMainWindow* p = actionCollection->m_pMainWindow;
-   KAction* a = new KAction( i18n("About")+" KDiff3", 0, parent, slot, actionCollection, "about_kdiff3", false, false );
+   TDEMainWindow* p = actionCollection->m_pMainWindow;
+   TDEAction* a = new TDEAction( i18n("About")+" KDiff3", 0, parent, slot, actionCollection, "about_kdiff3", false, false );
    if(p) a->addTo( p->helpMenu );
    return a;
 }
 
-KAction* KStdAction::aboutTQt( KActionCollection* actionCollection )
+TDEAction* KStdAction::aboutTQt( TDEActionCollection* actionCollection )
 {
-   KMainWindow* p = actionCollection->m_pMainWindow;
-   KAction* a = new KAction( i18n("About")+" TQt", 0, tqApp, TQT_SLOT(aboutTQt()), actionCollection, "about_qt", false, false );
+   TDEMainWindow* p = actionCollection->m_pMainWindow;
+   TDEAction* a = new TDEAction( i18n("About")+" TQt", 0, tqApp, TQT_SLOT(aboutTQt()), actionCollection, "about_qt", false, false );
    if(p) a->addTo( p->helpMenu );
    return a;
 }
 
-KAction* KStdAction::help( TQWidget* parent, const char* slot, KActionCollection* actionCollection)
+TDEAction* KStdAction::help( TQWidget* parent, const char* slot, TDEActionCollection* actionCollection)
 {
-   KMainWindow* p = actionCollection->m_pMainWindow;
-   KAction* a = new KAction( i18n("Help"), TQt::Key_F1, parent, slot, actionCollection, "help", false, false );
+   TDEMainWindow* p = actionCollection->m_pMainWindow;
+   TDEAction* a = new TDEAction( i18n("Help"), TQt::Key_F1, parent, slot, actionCollection, "help", false, false );
    if(p) a->addTo( p->helpMenu );
    return a;
 }
-KAction* KStdAction::find( TQWidget* parent, const char* slot, KActionCollection* actionCollection)
+TDEAction* KStdAction::find( TQWidget* parent, const char* slot, TDEActionCollection* actionCollection)
 {
-   KMainWindow* p = actionCollection->m_pMainWindow;
-   KAction* a = new KAction( i18n("Find"), TQt::CTRL+TQt::Key_F, parent, slot, actionCollection, "find", false, false );
+   TDEMainWindow* p = actionCollection->m_pMainWindow;
+   TDEAction* a = new TDEAction( i18n("Find"), TQt::CTRL+TQt::Key_F, parent, slot, actionCollection, "find", false, false );
    if(p) a->addTo( p->editMenu );
    return a;
 }
 
-KAction* KStdAction::findNext( TQWidget* parent, const char* slot, KActionCollection* actionCollection)
+TDEAction* KStdAction::findNext( TQWidget* parent, const char* slot, TDEActionCollection* actionCollection)
 {
-   KMainWindow* p = actionCollection->m_pMainWindow;
-   KAction* a = new KAction( i18n("Find Next"), TQt::Key_F3, parent, slot, actionCollection, "findNext", false, false );
+   TDEMainWindow* p = actionCollection->m_pMainWindow;
+   TDEAction* a = new TDEAction( i18n("Find Next"), TQt::Key_F3, parent, slot, actionCollection, "findNext", false, false );
    if(p) a->addTo( p->editMenu );
    return a;
 }
@@ -727,7 +727,7 @@ KAction* KStdAction::findNext( TQWidget* parent, const char* slot, KActionCollec
 
 
 
-KFontChooser::KFontChooser( TQWidget* pParent, const TQString& /*name*/, bool, const TQStringList&, bool, int )
+TDEFontChooser::TDEFontChooser( TQWidget* pParent, const TQString& /*name*/, bool, const TQStringList&, bool, int )
 : TQWidget(pParent)
 {
    m_pParent = pParent;
@@ -745,19 +745,19 @@ KFontChooser::KFontChooser( TQWidget* pParent, const TQString& /*name*/, bool, c
    pLayout->addWidget(m_pLabel);
 }
 
-TQFont KFontChooser::font()
+TQFont TDEFontChooser::font()
 {
    return m_font;//TQFont("courier",10);
 }
 
-void KFontChooser::setFont( const TQFont& font, bool )
+void TDEFontChooser::setFont( const TQFont& font, bool )
 {
    m_font = font;
    m_pLabel->setFont( m_font );
    //update();
 }
 
-void KFontChooser::slotSelectFont()
+void TDEFontChooser::slotSelectFont()
 {
    for(;;)
    {
@@ -842,12 +842,12 @@ void KPrinter::setPageSelection(e_PageSelection)
 }
 
 
-TQPixmap KIconLoader::loadIcon( const TQString&, int )
+TQPixmap TDEIconLoader::loadIcon( const TQString&, int )
 {
    return TQPixmap();
 }
 
-KAboutData::KAboutData( const TQString& /*name*/, const TQString& appName, const TQString& version,
+TDEAboutData::TDEAboutData( const TQString& /*name*/, const TQString& appName, const TQString& version,
       const TQString& description, int,
       const TQString& copyright, int, const TQString& homepage, const TQString& email)
 {
@@ -859,16 +859,16 @@ KAboutData::KAboutData( const TQString& /*name*/, const TQString& appName, const
    s_homepage = homepage;
 }
 
-KAboutData::KAboutData( const TQString& /*name*/, const TQString& /*appName*/, const TQString& /*version*/ )
+TDEAboutData::TDEAboutData( const TQString& /*name*/, const TQString& /*appName*/, const TQString& /*version*/ )
 {
 }
 
-void KAboutData::addAuthor(const char* name, const char* task, const char* email, const char* weblink)
+void TDEAboutData::addAuthor(const char* name, const char* task, const char* email, const char* weblink)
 {
    m_authorList.push_back( AboutDataEntry( name, task, email, weblink) );
 }
 
-void KAboutData::addCredit(const char* name, const char* task, const char* email, const char* weblink)
+void TDEAboutData::addCredit(const char* name, const char* task, const char* email, const char* weblink)
 {
    m_creditList.push_back( AboutDataEntry( name, task, email, weblink) );
 }
@@ -883,46 +883,46 @@ void KAboutData::addCredit(const char* name, const char* task, const char* email
   { "+[File3]", I18N_NOOP("file3 to open"), 0 },
 */
 ////////////////
-static KCmdLineArgs s_cmdLineArgs;
+static TDECmdLineArgs s_cmdLineArgs;
 static int s_argc;
 static char** s_argv;
-static KCmdLineOptions* s_pOptions;
+static TDECmdLineOptions* s_pOptions;
 
 static std::vector<QCStringList> s_vOption;
 static std::vector<const char*> s_vArg;
 
-KCmdLineArgs* KCmdLineArgs::parsedArgs()  // static
+TDECmdLineArgs* TDECmdLineArgs::parsedArgs()  // static
 {
    return &s_cmdLineArgs;
 }
 
-void KCmdLineArgs::init( int argc, char**argv, KAboutData* pAboutData )  // static
+void TDECmdLineArgs::init( int argc, char**argv, TDEAboutData* pAboutData )  // static
 {
    s_argc = argc;
    s_argv = argv;
    s_pAboutData = pAboutData;
 }
 
-void KCmdLineArgs::addCmdLineOptions( KCmdLineOptions* options ) // static
+void TDECmdLineArgs::addCmdLineOptions( TDECmdLineOptions* options ) // static
 {
    s_pOptions = options;
 }
 
-int KCmdLineArgs::count()
+int TDECmdLineArgs::count()
 {
    return s_vArg.size();
 }
 
-TQString KCmdLineArgs::arg(int idx)
+TQString TDECmdLineArgs::arg(int idx)
 {
    return TQString::fromLocal8Bit( s_vArg[idx] );
 }
 
-void KCmdLineArgs::clear()
+void TDECmdLineArgs::clear()
 {
 }
 
-TQString KCmdLineArgs::getOption( const TQString& s )
+TQString TDECmdLineArgs::getOption( const TQString& s )
 {
    // Find the option
    int j=0;
@@ -941,7 +941,7 @@ TQString KCmdLineArgs::getOption( const TQString& s )
    return TQString();
 }
 
-QCStringList KCmdLineArgs::getOptionList( const TQString& s )
+QCStringList TDECmdLineArgs::getOptionList( const TQString& s )
 {   
    // Find the option
    int j=0;
@@ -961,7 +961,7 @@ QCStringList KCmdLineArgs::getOptionList( const TQString& s )
    return QCStringList();
 }
 
-bool KCmdLineArgs::isSet(const TQString& s)
+bool TDECmdLineArgs::isSet(const TQString& s)
 {
    // Find the option
    int j=0;
@@ -978,9 +978,9 @@ bool KCmdLineArgs::isSet(const TQString& s)
 }
 
 ///////////////////
-KApplication* kapp;
+TDEApplication* kapp;
 
-KApplication::KApplication()
+TDEApplication::TDEApplication()
 : TQApplication( s_argc,s_argv )
 {
    kapp = this;
@@ -1109,28 +1109,28 @@ KApplication::KApplication()
    }
 }
 
-KConfig* KApplication::config()
+TDEConfig* TDEApplication::config()
 {
    return &m_config;
 }
 
-bool KApplication::isRestored()
+bool TDEApplication::isRestored()
 {
    return false;
 }
 
-KApplication* KApplication::kApplication()
+TDEApplication* TDEApplication::kApplication()
 {
    return kapp;
 }
 
-KIconLoader* KApplication::iconLoader()
+TDEIconLoader* TDEApplication::iconLoader()
 {
    return &m_iconLoader;
 }
 
 
-namespace KIO
+namespace TDEIO
 {
    SimpleJob* mkdir( KURL ){return 0;}
    SimpleJob* rmdir( KURL ){return 0;}
@@ -1145,12 +1145,12 @@ namespace KIO
    TransferJob* put( KURL, int, bool, bool, bool ){return (TransferJob*)0;}
 };
 
-KActionCollection* KParts::Part::actionCollection()
+TDEActionCollection* KParts::Part::actionCollection()
 {
    return 0;
 }
 
-KApplication* KParts::Part::instance()
+TDEApplication* KParts::Part::instance()
 {
    return kapp;
 }
